@@ -7,7 +7,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
 	AIC model test   R O U T I N E S
 
 	Peter Beerli 2001, Seattle
-	beerli@scs.fsu.edu
+	beerli@fsu.edu
 
 	Copyright 2001-2002 Peter Beerli and Joseph Felsenstein
 
@@ -15,7 +15,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
 	and is copyrighted. Of course, we do not guarantee that the software
 	works and are not responsible for any damage you may cause or have.
 
-$Id: aic.c 1088 2007-12-21 20:50:44Z beerli $ 
+$Id: aic.c 1702 2010-06-14 14:18:13Z beerli $ 
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -281,7 +281,7 @@ akaike_information (world_fmt * world, long *Gmax)
     myfree(aic.param0);
     myfree(temppattern);
     destroy_nr (nr, world);
-    myfree(nr);
+    //myfree(nr);
 }
 
 ///
