@@ -10,7 +10,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  
  
  Peter Beerli 1997, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
  Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
@@ -19,7 +19,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
- $Id: broyden.c 920 2007-09-25 17:13:42Z beerli $
+ $Id: broyden.c 1800 2011-01-29 13:40:00Z beerli $
 -------------------------------------------------------*/
 /*! \file broyden.c
 Basic routines for maximum likelihood parameter estimation.
@@ -664,7 +664,7 @@ calc_locus_like (nr_fmt * nr, MYREAL *param, MYREAL *lparam, long locus)
         //apg0r = apg0[r][locus];
         tyme = nr->atl[r][locus];
         // first element
-        tl = &(tyme.tl[0]);
+   //xcode     tl = &(tyme.tl[0]);
         // first element
         apg[0] -= apgmax;
         nr->PGC[locus] += EXP (apg[0]);
@@ -1190,14 +1190,16 @@ void
 gradient (MYREAL *d, nr_fmt * nr, long locus)
 {
     boolean found=FALSE;
-    MYREAL tk1,m1,th1,th2,l1,nm1;
+    MYREAL tk1,m1,th1,l1;
+    //MYREAL nm1,th2;
     //MYREAL nm2, l2, m2, tk2;
     long z, r;
     long other , otherpop;
     long g, i, ii, pop, msta, msto;
     long numpop = nr->numpop;
     long nn = nr->partsize - nr->profilenum;
-    MYREAL expapg, *thetas, *m;
+    MYREAL expapg, *thetas;
+    //MYREAL *m;
     MYREAL *geo = nr->world->data->geo;
     tarchive_fmt *tl;
     MYREAL tet;
@@ -1209,7 +1211,7 @@ gradient (MYREAL *d, nr_fmt * nr, long locus)
     normalgrad = (MYREAL *) mymalloc(nr->numpop2 * sizeof(MYREAL));
     memset (d, 0, sizeof (MYREAL) * nr->numpop2);
     thetas = nr->param;
-    m = nr->param + numpop;
+  //xcode  m = nr->param + numpop;
     for (r = nr->repstart; r < nr->repstop; r++)
     {
         for (pop = 0; pop < nr->numpop2; pop++)
@@ -1231,8 +1233,8 @@ gradient (MYREAL *d, nr_fmt * nr, long locus)
                 nr->parts[pop] = (- mu_rate * tet * (tl[g].p[pop] + normalgrad[pop] * tet)  + tl[g].kt[pop]) * rtet ;
                 msta = nr->mstart[pop];
                 msto = nr->mend[pop];
-                z = 0;
-                found=FALSE;
+             //xcode   z = 0;
+             //xcode   found=FALSE;
                 for (i = msta; i < msto; i++)
                 {
                     if (nr->param[i] > 0.)
@@ -1249,8 +1251,8 @@ gradient (MYREAL *d, nr_fmt * nr, long locus)
                                 nr->parts[i] = ((l1 / m1) - tk1) - normalgrad[i];
                             }
                             symmetric_other(i, numpop, &other, &otherpop);
-                            th2 = nr->param[otherpop];
-                            nm1 = m1 * th1;
+                        //xcode    th2 = nr->param[otherpop];
+                           //xcode nm1 = m1 * th1;
                             // speed opt: nr->parts[pop]  += tk1 * m1/th1 - l1/th1;
                             nr->parts[pop]  += tk1 * (m1 - l1)/th1;
                         }
@@ -1472,7 +1474,7 @@ calc_same_d (MYREAL *grad, nr_fmt * nr, long nn, long start, long stop)
             }
         }
         dt /= nsum;
-        z = 0;
+     //xcode   z = 0;
         for (i = start; i < stop; i++)
         {
             if (custm[i] == 'm')
@@ -1514,7 +1516,7 @@ calc_symmetric_d (MYREAL *grad, nr_fmt * nr, long nn, long start, long stop)
             dt += grad[i];
         }
         dt /= (stop - start);
-        z = 0;
+     //xcode   z = 0;
         for (i = start; i < stop; i++)
         {
             grad[i] = dt;
@@ -1543,41 +1545,41 @@ void
 check_symmetric_d (MYREAL *grad, nr_fmt * nr, long nn)
 {
     char *custm = NULL;
-    long zeron = 0;
-    long constn = 0;
+    //long zeron = 0;
+    //long constn = 0;
     long symn = 0;
     long sym2n = 0;
-    long mmn = 0;
+    //long mmn = 0;
     long numpop = 0;
     /*static boolean done = FALSE; */
     twin_fmt *syms = NULL;
     quad_fmt *sym2s = NULL;
-    long *zeros = NULL;
-    long *consts = NULL;
-    long *mms = NULL;
+   //xcode  long *zeros = NULL;
+   //xcode  long *consts = NULL;
+   //xcode  long *mms = NULL;
     long count;
     long z = 0, zz = 0, i;
     char *p;
     MYREAL mm, sq1, sq2;
 
 
-    custm = nr->world->options->custm2;
-    zeron = nr->world->options->zeron;
-    constn = nr->world->options->constn;
+    //xcode custm = nr->world->options->custm2;
+    //xcode zeron = nr->world->options->zeron;
+    //xcode constn = nr->world->options->constn;
     symn = nr->world->options->symn;
     sym2n = nr->world->options->sym2n;
-    mmn = nr->world->options->mmn;
+    //xcode mmn = nr->world->options->mmn;
     if (symn > 0)
         syms = nr->world->options->symparam;
     if (sym2n > 0)
         sym2s = nr->world->options->sym2param;
-    if (zeron > 0)
-        zeros = nr->world->options->zeroparam;
-    if (constn > 0)
-        consts = nr->world->options->constparam;
-    if (mmn > 0)
-        mms = nr->world->options->mmparam;
-    p = custm;
+    //xcode if (zeron > 0)
+    //xcode    zeros = nr->world->options->zeroparam;
+    //xcode if (constn > 0)
+    //xcode    consts = nr->world->options->constparam;
+    //xcode if (mmn > 0)
+    //xcode    mms = nr->world->options->mmparam;
+    //xcode p = custm;
     custm = nr->world->options->custm2;
     numpop = nr->numpop;
     p = custm;
