@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1754 2010-10-29 01:51:00Z beerli $
+$Id: data.c 1814 2011-03-20 17:21:07Z beerli $
 
 -----------------------------------
 add this to the microsatellite data, this will allow to use
@@ -753,6 +753,9 @@ read_sites (data_fmt * data, world_fmt *world, option_fmt *options)
     long locus;
     char *input;
     char * word;
+    long oldi;
+    long i;
+    long len;
     long z=0; //z is adding subloci and is reset with a closing ')'
     long zz=0; //zz is used for mutationmodels and is not reset at closing ')'
     input = (char *) mycalloc(allocbufsize ,sizeof(char));
@@ -772,9 +775,9 @@ read_sites (data_fmt * data, world_fmt *world, option_fmt *options)
 		{
 		  FGETS2(&input,&allocbufsize,data->infile); // read the line 
 		  locus--;
-		  long oldi=0;
-		  long i;
-		  long len=0;
+		  oldi=0;
+		  // long i;
+		  len=0;
 		  data->has_repeats = FALSE;
 		  for(i = 0 ; i < data->loci; i++)
 		    {
@@ -2007,7 +2010,7 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
 #endif
 	}
       fprintf(outfile,"Total ");
-      for (pop = 0; pop1 < data->numpop; pop1++)
+      for (pop1 = 0; pop1 < data->numpop; pop1++)
 	{
 	  pop = options->newpops[pop1]-1;
 	  fprintf(outfile," %5li ",maxallelepop[pop]);
@@ -2159,9 +2162,13 @@ MYREAL findleastsquare(MYREAL *rawdata, long total, long repeatlength, long shif
 {
   long i;
   long j;
+  long high;
+  long low;
   MYREAL lowvalue=MYREAL_MAX;
   MYREAL highvalue=0.;
   MYREAL sum = 0.0;
+  MYREAL value;
+  MYREAL oldvalue;
   for(i=0;i<total;i++)
     {
       if(rawdata[i] < lowvalue)
@@ -2169,14 +2176,12 @@ MYREAL findleastsquare(MYREAL *rawdata, long total, long repeatlength, long shif
       if(rawdata[i]> highvalue)
 	highvalue = rawdata[i];
     }
-  long high = (long) (highvalue+repeatlength+shift);
-  long low  = (long) (lowvalue -repeatlength+shift);
+  high = (long) (highvalue+repeatlength+shift);
+  low  = (long) (lowvalue -repeatlength+shift);
   if(low<0){
     low = 0;
   }
   *startvalue = low;
-  MYREAL value;
-  MYREAL oldvalue;
   for(i=0;i<total;i++)
     {
       oldvalue = MYREAL_MAX;
@@ -2196,22 +2201,36 @@ MYREAL findleastsquare(MYREAL *rawdata, long total, long repeatlength, long shif
 
 void find_allele_repeatlength(data_fmt *data, option_fmt *options, long locus)
 {
+  long z=0;
   long zz=0;
   long pop;
   long ind;
   long r;
+  MYREAL *rawdata;
+  char *a1;
+  char *a2;
+  long total=z;
+  MYREAL minLS=MYREAL_MAX;
+  MYREAL value;
+  long intval;
+  MYREAL startvalue= 0.0;
+  MYREAL keepstartvalue= 0.0;
+  MYREAL leastsquare;
+  MYREAL nonfloored;
+  MYREAL floored;
+  MYREAL diff;
   for (pop = 0; pop < data->numpop; pop++)
     {
       zz += data->numind[pop][locus];
     }
-  MYREAL * rawdata = (MYREAL *) calloc(2 * zz, sizeof(MYREAL));
-  long z=0;
+  rawdata = (MYREAL *) calloc(2 * zz, sizeof(MYREAL));
+
   for (pop = 0; pop < data->numpop; pop++)
     {
       for (ind = 0; ind < data->numind[pop][locus]; ind++)
 	{
-	  char *a1 = data->yy[pop][ind][locus][0];
-	  char *a2 = data->yy[pop][ind][locus][1];
+	  a1 = data->yy[pop][ind][locus][0];
+	  a2 = data->yy[pop][ind][locus][1];
 	  if (a1[0]!='?')
 	    {
 	      rawdata[z++] = atof(a1);
@@ -2222,21 +2241,20 @@ void find_allele_repeatlength(data_fmt *data, option_fmt *options, long locus)
 	    }
 	}
     }
-  long total=z;
-  MYREAL minLS=MYREAL_MAX;
-  long keepr=0;
-  MYREAL value;
-  long intval;
-  MYREAL startvalue= 0.0;
-  MYREAL keepstartvalue= 0.0;
+
+  total=z;
+  minLS=MYREAL_MAX;
+  startvalue= 0.0;
+  keepstartvalue= 0.0;
+
   for(r=0;r<data->repeatlength[locus];r++)
     {
       //MYREAL endvalue  = 0.0;
-      MYREAL leastsquare=findleastsquare(rawdata,total,data->repeatlength[locus],r,&startvalue);
+      leastsquare=findleastsquare(rawdata,total,data->repeatlength[locus],r,&startvalue);
       if(leastsquare < minLS)
 	{
 	  minLS = leastsquare;
-	  keepr = r;
+	 // keepr = r;
 	  keepstartvalue = startvalue;
 	}
     }
@@ -2244,24 +2262,24 @@ void find_allele_repeatlength(data_fmt *data, option_fmt *options, long locus)
     {
       for (ind = 0; ind < data->numind[pop][locus]; ind++)
 	{
-	  char *a1 = data->yy[pop][ind][locus][0];
-	  char *a2 = data->yy[pop][ind][locus][1];
+	  a1 = data->yy[pop][ind][locus][0];
+	  a2 = data->yy[pop][ind][locus][1];
 	  if (a1[0]!='?')
 	    {
 	      value = atof(a1);
 	      //Floor[(279.47 - 259)/4 + If[(Random[]) < 1 - FractionalPart[(279.47 - 259)/4 ], 0, 1]], {1000}] // Tally
-	      MYREAL nonfloored = (value - keepstartvalue)/data->repeatlength[locus]; 
-	      MYREAL floored = floor(nonfloored);
-	      MYREAL diff = nonfloored - floored; 
+	      nonfloored = (value - keepstartvalue)/data->repeatlength[locus]; 
+	      floored = floor(nonfloored);
+	      diff = nonfloored - floored; 
 	      intval = (long) floored + (RANDUM() < (1.0-diff) ? 0 : 1); 
 	      sprintf(data->yy[pop][ind][locus][0],"%li",intval);
 	    }
 	  if (a2[0]!='?')
 	    {
 	      value = atof(a2);
-	      MYREAL nonfloored = (value - keepstartvalue)/data->repeatlength[locus]; 
-	      MYREAL floored = floor(nonfloored);
-	      MYREAL diff = nonfloored - floored; 
+	      nonfloored = (value - keepstartvalue)/data->repeatlength[locus]; 
+	      floored = floor(nonfloored);
+	      diff = nonfloored - floored; 
 	      intval = (long) floored + (RANDUM() < (1.0-diff) ? 0 : 1); 
 	      sprintf(data->yy[pop][ind][locus][1],"%li",intval);
 	    }
