@@ -15,7 +15,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: gammalike.c 1323 2008-07-25 19:13:48Z beerli $
+$Id: gammalike.c 1800 2011-01-29 13:40:00Z beerli $
 */
 /*! \file gammalike.c 
 
@@ -110,7 +110,7 @@ gamma_loci_like_iterative(helper_fmt * helper, MYREAL *oparam, MYREAL *olparam,
             fha = fa;
             ha  = a;
             a = m;
-            fa = fm;
+           //xcode  fa = fm;
         }
         m = (ha + la)/2.;
         fa = find_gamma_summ( m,  theta1, nr,  oparam, olparam,  locus, helper);
