@@ -7,11 +7,11 @@
 // and for its derivatives
 #include "migration.h"
 
-extern MYREAL gamma_loci_like (helper_fmt * helper, MYREAL *oparam,
+MYREAL gamma_loci_like (helper_fmt * helper, MYREAL *oparam,
                                    MYREAL *olparam, MYREAL denom);
-extern MYREAL gamma_locus_like (nr_fmt * nr, MYREAL *oparam, MYREAL *olparam,
+MYREAL gamma_locus_like (nr_fmt * nr, MYREAL *oparam, MYREAL *olparam,
                                     MYREAL denom, long locus);
-extern void gamma_loci_derivative (helper_fmt * helper);
-extern void gamma_locus_derivative (helper_fmt * helper, long locus);
-extern void gamma_loci_difference (helper_fmt * helper);
+void gamma_loci_derivative (helper_fmt * helper);
+void gamma_locus_derivative (helper_fmt * helper, long locus);
+void gamma_loci_difference (helper_fmt * helper);
 #endif
