@@ -9,12 +9,12 @@
  
  moved out from world.c                                                                                                               
  Peter Beerli 2000, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: lrt.h 514 2006-11-09 20:14:08Z beerli $
+$Id: lrt.h 1323 2008-07-25 19:13:48Z beerli $
 -------------------------------------------------------*/
 
 extern void print_lratio_test (world_fmt * world, long *Gmax);
