@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1748 2010-10-25 00:42:42Z beerli $*/
+/* $Id: main.c 1857 2011-03-24 18:24:18Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -97,11 +97,20 @@ int locidone;	  /*!< used in MPI workers
 long unique_id_global;
 #ifdef MPI
 #ifdef  USE_MYREAL_FLOAT
+#ifdef WINDOWS
+#define mpisizeof MPI_FLOAT ;
+#else
 const MPI_Datatype mpisizeof = MPI_FLOAT ;
+#endif
+#else
+#ifdef WINDOWS
+//#define mpisizeof MPI_DOUBLE ;
+ MPI_Datatype mpisizeof ;
 #else
 const  MPI_Datatype mpisizeof = MPI_DOUBLE ;
 #endif
 #endif
+#endif
 
 #ifdef CAUTIOUS
 boolean cautious; /*!< forces a check whether a file exists and will ask before overwriting           */
@@ -238,7 +247,7 @@ prepare_next_chain (world_fmt ** universe, worldoption_fmt * options,
 
 void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options);
 #ifdef MPI
-void fix_bayesfactor(world_fmt *world, option_fmt * options);
+//void fix_bayesfactor(world_fmt *world, option_fmt * options);
 void      print_marginal_like(float *temp, long *z, world_fmt * world);
 #else /*not MPI*/
 void      print_marginal_like(char *temp, long *c, world_fmt * world);
@@ -315,6 +324,9 @@ main (int argc, char **argv)
   world_fmt **universe;
 #ifdef MPI
   int       server;
+#ifdef WINDOWS
+ mpisizeof = MPI_DOUBLE ;
+#endif
 #endif
 #ifdef HAVE_NICE
   nice (10); //nice value arbitrarily set to 10, 5 is still nice, 0 is standard
@@ -324,9 +336,11 @@ main (int argc, char **argv)
   //---------------------------------------------------------------------------------------------
   // windows specific code for pretty printing
 #ifdef PRETTY
+#ifndef MPI
 #ifdef WIN32
     set_haru_handler();
 #endif
+#endif
 #endif
 
     //---------------------------------------------------------------------------------------------
@@ -566,7 +580,7 @@ main (int argc, char **argv)
 	  {
 	// print marginal likelihoods
 #ifdef MPI
-	    fix_bayesfactor(EARTH,options);
+	    //    fix_bayesfactor(EARTH,options);
 #endif
 	    print_bayesfactor(EARTH->outfile, universe,options);
 	// printing of MCMC run characteristics
@@ -633,6 +647,9 @@ main (int argc, char **argv)
 	      {
 		fprintf(EARTH->outfile,"%5li %10.5f\n",locus+1,universe[locus]->averageheat);
 	      }
+	    fprintf(EARTH->outfile,"Adaptive heating often fails, if the average temperatures are very close together\n");
+	    fprintf(EARTH->outfile,"try to rerun using static heating! If you want to compare models using marginal\n");
+	    fprintf(EARTH->outfile,"likelihoods then you MUST use static heating\n");
 	    pdf_print_averageheat(universe,options);
 	  }
 	//
@@ -1207,10 +1224,12 @@ heated_swap (world_fmt ** universe, worldoption_fmt * options)
             MERKUR->swapped += sm;
             break;
         case 1:
-            VENUS->swapped += (mv = chance_swap_tree (MERKUR, VENUS));
+            mv = chance_swap_tree (MERKUR, VENUS);
+            VENUS->swapped += mv;
             break;
         case 0:
-            EARTH->swapped += (vw = chance_swap_tree (VENUS, EARTH));
+            vw = chance_swap_tree (VENUS, EARTH);
+            EARTH->swapped += vw;
             break;
         default:
             universe[r]->swapped += chance_swap_tree (universe[r + 1], universe[r]);
@@ -1335,7 +1354,8 @@ print_heating_progress2 (FILE * file, worldoption_fmt * options,
   plogsize += sprintf (plog + plogsize,"           %10.4f  |   %4.2f   |    %5li  ||\n",
 		       universe[1]->averageheat, universe[1]->accept_freq,
 		       universe[1]->swapped);
-  plogsize += sprintf (plog + plogsize,"           %10.4f  |   %4.2f   |    %5li   |\n",
+  //xcode plogsize += 
+    sprintf (plog + plogsize,"           %10.4f  |   %4.2f   |    %5li   |\n",
 		       universe[0]->averageheat, universe[0]->accept_freq,
 		       universe[0]->swapped);
   FPRINTF(file,"%s",plog);
@@ -1371,13 +1391,17 @@ analyze_olddata (world_fmt * world,
         }
         
 #ifdef MPI
-        
-        MYMPIBCAST (data->geo, world->numpop2, mpisizeof, MASTER, comm_world);
-        MYMPIBCAST (data->lgeo, world->numpop2, mpisizeof, MASTER, comm_world);
+#ifdef WINDOWS	
+        MYMPIBCAST (data->geo, world->numpop2, MPI_DOUBLE, MASTER, comm_world );
+        MYMPIBCAST (data->lgeo, world->numpop2, MPI_DOUBLE, MASTER, comm_world );
+#else
+        MYMPIBCAST (data->geo, world->numpop2, mpisizeof, MASTER, comm_world );
+        MYMPIBCAST (data->lgeo, world->numpop2, mpisizeof, MASTER, comm_world );
+#endif
     }
     else
     {
-        MYMPIBCAST (listofthings, 6, MPI_LONG, MASTER, comm_world);
+        MYMPIBCAST (listofthings, 6, MPI_LONG, MASTER, comm_world );
         //      printf("listofthings received\n");
         //    fflush(stdout);
         world->loci = listofthings[0];
@@ -1389,9 +1413,13 @@ analyze_olddata (world_fmt * world,
         data->numpop = world->numpop;
         data->geo = (MYREAL *) mycalloc (1, sizeof (MYREAL) * world->numpop2);
         data->lgeo = (MYREAL *) mycalloc (1, sizeof (MYREAL) * world->numpop2);
-        
+#ifdef WINDOWS
+        MYMPIBCAST (data->geo, world->numpop2, MPI_DOUBLE, MASTER, comm_world);
+        MYMPIBCAST (data->lgeo, world->numpop2, MPI_DOUBLE, MASTER, comm_world);
+#else
         MYMPIBCAST (data->geo, world->numpop2, mpisizeof, MASTER, comm_world);
         MYMPIBCAST (data->lgeo, world->numpop2, mpisizeof, MASTER, comm_world);
+#endif
         options->muloci = data->loci = world->loci;
         init_world (world, data, options);
 #endif
@@ -1462,6 +1490,9 @@ analyze_olddata (world_fmt * world,
 
 boolean analyze_oldbayesdata(world_fmt *world, option_fmt *options, data_fmt *data, long *outfilepos)
 {
+#ifdef MPI
+  long pop;
+#endif
   long locus;
   // read data from bayesfile
   world->cold=TRUE;
@@ -1476,7 +1507,6 @@ boolean analyze_oldbayesdata(world_fmt *world, option_fmt *options, data_fmt *da
       alloc_sticksize(options,data);
       options->newpops_numalloc = world->numpop;
       options->newpops = (long*) mycalloc(options->newpops_numalloc, sizeof(long));
-      long pop;
       for(pop=0;pop<world->numpop;pop++)
 	options->newpops[pop]=pop+1;
       init_world (world, data, options);
@@ -2069,24 +2099,12 @@ run_updates (world_fmt ** universe,
         dispatch_queue_t queue = dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0);
         dispatch_apply(options->heated_chains, queue,
                        ^(unsigned long ii) {
-#ifdef FUNNYHEAT
-			 if(ii!=0)
-			   {
-			     reset_weight(universe[ii]);
-			   }
-#endif
                          run_one_update (universe[ii]);
                        }
                        );
 #else
         for (ii = 0; ii < options->heated_chains; ii++)
         {
-#ifdef FUNNYHEAT
-	  if(ii!=0)
-	    {
-	      reset_weight(universe[ii]);
-	    }
-#endif
 	  run_one_update (universe[ii]);
         }
 #endif /*SNOWLEOPARD*/
@@ -2300,13 +2318,13 @@ run_chains (world_fmt ** universe,
         if (EARTH->options->heating)
 	  {
 	    //            print_heating_progress (universe, EARTH->options, EARTH->options->heating_interval * increment * steps * treeupdateratio);
-            print_heating_progress (universe, EARTH->options, increment * steps * treeupdateratio);
+            print_heating_progress (universe, EARTH->options, (long) increment * steps * treeupdateratio);
 	    reset_heated_accept(universe,EARTH->options->heated_chains);
 	  }
         else
 	  {
             print_progress (EARTH->options, EARTH, rep,
-                            increment * steps * treeupdateratio, (long) EARTH->accept_freq);
+                            (long) increment * steps * treeupdateratio, (long) EARTH->accept_freq);
 	    EARTH->accept_freq = 0. ;
 	    EARTH->accept = 0L ;
 	  }
@@ -2352,10 +2370,10 @@ run_replicate (long locus,
   //  long i,j;
     long chains = 0;
     char type = 's';
-    long pluschain;
+    //long pluschain;
     long runs;
     long increment = 1;
-    long steps;
+    //long steps;
     long oldsteps = 0;
     /* loop over independent replicates----------------------- */
     /* but make sure that we get single chain estimates, too   */
@@ -2369,11 +2387,11 @@ run_replicate (long locus,
     type = 's';
     runs = 1;
     // rep = 0;
-    pluschain = options->pluschain;
+    //xcode pluschain = options->pluschain;
     //see obscure options
     /* short and long chains ----------------------------- */
     set_bounds (&increment, &oldsteps, &chains, options, type);
-    steps = oldsteps;
+    //xcode steps = oldsteps;
     EARTH->increment = increment;
     while (runs-- >= 0)
     {
@@ -2507,13 +2525,13 @@ MYREAL combine_scaling_factor(world_fmt *world)
 void print_bf_values(world_fmt * world)
 {
   long locus;
+  long t;
   const long hc = world->options->heated_chains;
   for(locus=0;locus<world->loci;locus++)
     {
       if(world->data->skiploci[locus])
 	continue;
       printf("=====> locus=%li ",locus );
-      long t;
       for(t=0; t < hc; t++)
 	{
 	  printf("%f ",world->bf[locus*hc+t]);
@@ -2522,7 +2540,7 @@ void print_bf_values(world_fmt * world)
     }
 }
 
-#ifdef MPI
+#ifdef MPI_do_not_use
 void fix_bayesfactor(world_fmt *world, option_fmt * options)
 {
   return;
@@ -2555,9 +2573,9 @@ void fix_bayesfactor(world_fmt *world, option_fmt * options)
 
 void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 {
-#ifdef MPI
+  //#ifdef MPI
   //static boolean done=FALSE;
-#endif
+  //#endif
   long t;
   const long hc = EARTH->options->heated_chains;
   long locus;
