@@ -3,18 +3,19 @@
 // using the libharu PDF-package.
 //
 // Michal Palzcewski and Peter Beerli 2005
-#ifdef WIN32
+#ifdef WINDOWS
 #include <new.h>
+#ifndef MPI
 extern "C" {
   void set_haru_handler(void);
 }
 extern int throw_new_handler(size_t t);
-
 void set_haru_handler(void) 
 {
   _set_new_handler(throw_new_handler);
 }
 #endif
+#endif
 
 int dummy_function(int do_nothing)
 {
