@@ -16,7 +16,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: profile.c 1722 2010-10-09 15:27:25Z beerli $
+$Id: profile.c 1800 2011-01-29 13:40:00Z beerli $
  
 -------------------------------------------------------*/
 /*! \file profile.c
@@ -935,7 +935,8 @@ profile_max_percentiles (long which, MYREAL *likes, MYREAL **param,
 {
     const MYREAL probabilities[] = GRID;
 
-    long i, trials = 0;
+    long i;
+    //, trials = 0;
     long df;
     long len;
     boolean QD = FALSE, QD2 = FALSE;
@@ -1015,7 +1016,7 @@ profile_max_percentiles (long which, MYREAL *likes, MYREAL **param,
 
         memcpy (param[i], mlparam, sizeof (MYREAL) * len);
 
-        trials =
+        //xcode trials =
             find_profilelike (testlike, prob, i, minparam, maxparam, &param[i],
                               &likes[i], which, world, QD, QD2, mlparam, &normd,
                               nr);
@@ -1032,13 +1033,16 @@ profile_max_spline (char method, long which, MYREAL *likes, MYREAL **param,
 {
 
     MYREAL deviate[] = DEVIATE;
-    long errc;
+//xcode    long errc;
     long indeks[] = INDEX;
     const MYREAL probabilities[] = GRID;
-    long i, trials = 0;
+    long i;
+    //, trials = 0;
     long panic, df;
     long len;
-    MYREAL prob, normd, maxlike, testlike, minparam = 0, maxparam = 0;
+    MYREAL prob, normd, maxlike, testlike;
+    //, maxparam = 0;
+    //minparam = 0, 
     MYREAL *mlparam;
     MYREAL **hess;
     MYREAL tmp, x, xx, xlow, xhigh, mid, low, high, value;
@@ -1058,7 +1062,7 @@ profile_max_spline (char method, long which, MYREAL *likes, MYREAL **param,
                 (long) world->
                 options->gamma);
     /* the minimum */
-    minparam = which < world->numpop ? SMALLEST_THETA : SMALLEST_MIGRATION;
+    //xcode minparam = which < world->numpop ? SMALLEST_THETA : SMALLEST_MIGRATION;
     /* the maximum */
     if (world->loci > 1)
     {
@@ -1078,7 +1082,7 @@ profile_max_spline (char method, long which, MYREAL *likes, MYREAL **param,
 
     memcpy (param[nn - 1], mlparam, sizeof (MYREAL) * len);
     likes[nn - 1] = maxlike;
-    maxparam = param[nn - 1][which];
+    //xcode maxparam = param[nn - 1][which];
     /* calculate likelihood at GRIDNODES */
     for (i = 0; i < nn - 1; i++)
     {
@@ -1095,7 +1099,7 @@ profile_max_spline (char method, long which, MYREAL *likes, MYREAL **param,
         likes[i] = nr->llike;
         normd = nr->normd;
         memcpy (param[i], world->param0, sizeof (MYREAL) * nr->partsize);
-        trials = 1;
+        //xcode trials = 1;
         if (method != 's')
             prognose_profile_end (world->starttime,
                                   world->numpop2 + (long) world->options->gamma,
@@ -1110,10 +1114,8 @@ profile_max_spline (char method, long which, MYREAL *likes, MYREAL **param,
         prepare_spline_first (spline->param, spline->like);
         prepare_spline_last (nn, spline->param, spline->like);
         calc_spline_diff (spline->diff, spline->param, spline->like, nn);
-        errc =
-            calc_spline (spline->param, spline->like, nn, spline->constr,
-                         spline->diff, spline->diff2, spline->diagn, spline->work,
-                         spline->nwork);
+        calc_spline (spline->param, spline->like, nn, spline->constr,
+                    spline->diff, spline->diff2, spline->diagn, spline->work,spline->nwork);
         for (i = 0; i < nn - 1; i++)
         {
             if (probabilities[i] < 0.5)
@@ -1169,7 +1171,7 @@ profile_max_spline (char method, long which, MYREAL *likes, MYREAL **param,
             likes[i] = nr->llike;
             normd = nr->normd;
             memcpy (param[i], world->param0, sizeof (MYREAL) * nr->partsize);
-            x = LOG (xx);
+            //xcode x = LOG (xx);
             prognose_profile_end (world->starttime,
                                   world->numpop2 + (long) world->options->gamma,
                                   nn);
@@ -1347,7 +1349,8 @@ set_profile_param (MYREAL *param, long which, long *allwhich,
 {
     boolean has_fixed = FALSE;
 
-    long z = 0, i = 0, zz = 0, zzz = 0; //zz is the counter for # fixed elements
+    long z = 0, i = 0, zz = 0;//zz is the counter for # fixed elements
+    //xcode zzz = 0; 
     long numpop = world->numpop;
     long numpop2 = world->numpop2;
     char *p;
@@ -1386,7 +1389,7 @@ set_profile_param (MYREAL *param, long which, long *allwhich,
         allwhich[0] = which, xvals[0] = xval;
         if (has_fixed)
         {
-            zzz = 0;
+            //xcode zzz = 0;
             addinvar (param, fixed, allwhich, xvals, 1, zz)
                 ;
             myfree(fixed)
