@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c 1776 2010-12-05 14:06:10Z beerli $
+$Id: random.c 1850 2011-03-21 20:08:31Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
 #include "sighandler.h"
@@ -38,7 +38,7 @@ $Id: random.c 1776 2010-12-05 14:06:10Z beerli $
 
 
 #ifdef MERSENNE_TWISTER
-#include "SFMT-src-1.2/SFMT.h"
+#include "SFMT.c"
 #endif
 
 #ifdef DMALLOC_FUNC_CHECK
@@ -439,15 +439,8 @@ unsigned long int random_seed()
   
   if ((devrandom = fopen("/dev/random","r")) == NULL) 
     {
-      //#ifndef WINDOWS
       gettimeofday(&tv,0);
-      //printf("in random_seed() %li + %li\n",tv.tv_sec,tv.tv_usec);
       seed = tv.tv_sec + tv.tv_usec;
-      //#else
-      //time(&seed);
-      //      seed = (unsigned int) rand();
-      //printf("in random_seed() %li\n",seed);
-      //#endif
     }
   else 
     {
