@@ -16,7 +16,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 1759 2010-11-06 01:16:48Z beerli $
+$Id: reporter.c 1866 2011-04-28 20:03:46Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -356,6 +356,9 @@ void print_bayes_ess(FILE *file, world_fmt *world, long numparam, int offset,
   bayes_fmt * bayes = world->bayes;
   char *buffer;
   long start=0;
+#ifdef MPI
+  long i;
+#endif
   //long locus = 1;
   if(!world->options->bayes_infer)
     start=world->numpop2;
@@ -432,7 +435,8 @@ void print_bayes_ess(FILE *file, world_fmt *world, long numparam, int offset,
     }
   if(world->loci>1 && file!=stdout)
     {
-      pos += sprintf(buffer+pos,"%*.*s(*) averaged over loci.\n", offset, offset, " ");
+      //xcode pos += 
+      sprintf(buffer+pos,"%*.*s(*) averaged over loci.\n", offset, offset, " ");
     }
   //  printf("bufsize in print_bayes_ess_buffer: %li\n",pos);
 #ifdef MPI
@@ -443,7 +447,7 @@ void print_bayes_ess(FILE *file, world_fmt *world, long numparam, int offset,
 	  //printf("bufsize in print_bayes_ess_buffer2: %li / %li\n",pos, numparam*LINESIZE);
 	  fprintf(file,"[%3i] %*.*s\n", myID, (int) LINESIZE, (int) LINESIZE, buffer);
 	  pos -= LINESIZE;
-	  long i=0;
+	  i=0;
 	  while(pos>LINESIZE)
 	    {
 	      i += LINESIZE;
@@ -466,7 +470,7 @@ void print_bayes_ess(FILE *file, world_fmt *world, long numparam, int offset,
 	  //printf("bufsize in print_bayes_ess_buffer4.1: %li\n",pos);
 	  fprintf(file,"[%3i] %*.*s\n", myID, (int) LINESIZE, (int) LINESIZE, buffer);
 	  pos -= LINESIZE;
-	  long i=0;
+	  i=0;
 	  while(pos>LINESIZE)
 	    {
 	      i += LINESIZE;
@@ -1278,3 +1282,50 @@ void convergence_progress(FILE *file, world_fmt *world)
   fprintf(file,"Maximum sqrt(R) = %f\n\n\n", world->convergence->gelmanmaxRall);
 }
 
+void methods(world_fmt *world)
+{
+    char title[] = "Method description suggestion:";
+    fprintf(world->outfile,"%s\n",title);
+    fprintf(world->outfile,"Migrate was run in %s with the following run time settings:",
+	    world->options->bayes_infer ? "Bayesian mode (Beerli and Felsenstein 1999, 2001; Beerli 1998,2006)" : 
+	    "Maximum Likelihood mode (Beerli 1998, Beerli and Felsenstein 1999, 2001)");
+    if (world->options->bayes_infer)
+      {
+	fprintf(world->outfile,"A total of x replicates were run. Each replicate represents a full\n");
+	fprintf(world->outfile,"MCMC run of one cold chain with x-1 heated connected chains. Each replicate\n");
+	fprintf(world->outfile,"visited a total of x states (Genealogy were visited with frequency of x and\n");
+	fprintf(world->outfile,"each parameter was visited with this average frequency x. The run parameters\n");
+	fprintf(world->outfile,"were set so that each locus sampled x observations from the visited states using\n");
+	fprintf(world->outfile,"an increment of y. We used uniform prior distributions with ranges of a to b\n" );
+	fprintf(world->outfile,"and c to d for Theta and M, respectively");
+      }
+}
+
+void citations(world_fmt *world)
+{
+  char title[] = "Citation suggestions:";
+  char texttitle[5][50]  = {"General method:", "Maximum likelihood:", "Bayesian inference:", "Likelihood ratio test:", "Bayes factors:"};
+  char citations[9][320]  = {"[1] P. Beerli, 1998. Estimation of migration rates and population sizes in geographically structured populations., in Advances in Molecular Ecology, G. R. Carvalho, ed., vol. 306 of NATO sciences series, Series A: Life sciences, ISO Press, Amsterdam, pp. 39–53.",\
+    "[2] P. Beerli and J. Felsenstein, 1999. Maximum-likelihood estimation of migration rates and effective popu- lation numbers in two populations using a coalescent approach, Genetics, 152:763–773.",\
+    "[3] P. Beerli and J. Felsenstein, 2001. Maximum likelihood estimation of a migration matrix and effective population sizes in n subpopulations by using a coalescent approach, Proceedings of the National Academy of Sciences of the United States of America, 98: p. 4563–4568.",\
+    "[4] P. Beerli, 2004. Effect of unsampled populations on the estimation of population sizes and migration rates between sampled populations, Molecular Ecology, 13: 827–836.",\
+      "[5] P. Beerli, 2006. Comparison of Bayesian and maximum-likelihood inference of population genetic parameters. Bioinformatics 22:341-345",\
+    "[6] P. Beerli, 2007. Estimation of the population scaled mutation rate from microsatellite data, Genetics, 177:1967–1968.",\
+    "[7] P. Beerli, 2009. How to use migrate or why are Markov chain Monte Carlo programs difficult to use?, in Population Genetics for Animal Conservation, G. Bertorelle, M. W. Bruford, H. C. Hauffe, A. Rizzoli, and C. Vernesi, eds., vol. 17 of Conservation Biology, Cambridge University Press, Cambridge UK, pp. 42–79.",\
+    "[8] P. Beerli and M. Palczewski, 2010. Unified framework to evaluate panmixia and migration direction among multiple sampling locations, Genetics, 185: 313–326."};
+
+    fprintf(world->outfile,"%s\n",title);
+//general
+    fprintf(world->outfile,"%s\n",texttitle[0]);
+    fprintf(world->outfile,"%s\n%s\n%s\n",citations[0],citations[6],citations[5]);
+//likelihood
+    fprintf(world->outfile,"%s\n",texttitle[1]);
+    fprintf(world->outfile,"%s\n%s\n",citations[1],citations[2]);
+//Bayesian inference
+    fprintf(world->outfile,"%s\n",texttitle[2]);
+    fprintf(world->outfile,"%s\n%s\n",citations[4],citations[8]);
+//likelihood
+    fprintf(world->outfile,"%s\n",texttitle[4]);
+    fprintf(world->outfile,"%s\n",citations[7]);
+
+}
