@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c 1759 2010-11-06 01:16:48Z beerli $
+ $Id: sequence.c 1860 2011-04-03 15:17:11Z beerli $
  
 -------------------------------------------------------*/
 /* \file sequence.c
@@ -388,7 +388,7 @@ getbasefreqs (option_fmt * options, seqmodel_fmt * seq, long locus)
   long l;
 
   register MYREAL freqa, freqc, freqg, freqt, freqr, freqy;
-  register MYREAL freqar, freqcy, freqgr, freqty;
+  register MYREAL /*freqar, freqcy,*/ freqgr, freqty;
 
   MYREAL aa, bb;
   if (locus == 0)
@@ -425,8 +425,8 @@ getbasefreqs (option_fmt * options, seqmodel_fmt * seq, long locus)
   seq->basefrequencies[NUC_CY]= freqc / freqy;
   seq->basefrequencies[NUC_GR]= freqg / freqr;
   seq->basefrequencies[NUC_TY]= freqt / freqy;
-  freqar = seq->basefrequencies[NUC_AR];
-  freqcy = seq->basefrequencies[NUC_CY];
+  //freqar = seq->basefrequencies[NUC_AR];
+  //freqcy = seq->basefrequencies[NUC_CY];
   freqgr = seq->basefrequencies[NUC_GR];
   freqty = seq->basefrequencies[NUC_TY];
 
@@ -1216,7 +1216,7 @@ sitescrunch2 (world_fmt * world, long sites, long i, long j, long locus)
     done = FALSE;
     while (!done)
     {
-        found = FALSE;
+        //found = FALSE;
         if (seq->aliasweight[i - 1] > 0)
             i++;
         else
@@ -1225,7 +1225,7 @@ sitescrunch2 (world_fmt * world, long sites, long i, long j, long locus)
                 j = i + 1;
             if (j <= sites)
             {
-                found = FALSE;
+                //found = FALSE;
                 do
                 {
                     found = (seq->aliasweight[j - 1] > 0);
@@ -1601,7 +1601,6 @@ treelike_seq (world_fmt * world, long locus)
     sitelike *x1;
     worldoption_fmt *opt;
     opt = world->options;
-    seq = world->data->seq[0];
     p = crawlback (world->root->next);
     summ = 0.0;
 
@@ -1710,7 +1709,7 @@ snp_invariants (contribarr invariants, world_fmt *world, long locus, phenotype x
 {
     worldoption_fmt *opt;
     seqmodel_fmt *seq =  world->data->seq[0];
-    MYREAL summ;
+    //MYREAL summ;
 
     sitelike *val;
     long i, j;
@@ -1721,7 +1720,7 @@ snp_invariants (contribarr invariants, world_fmt *world, long locus, phenotype x
     freqt = seq->basefrequencies[NUC_T];
 
     opt = world->options;
-    summ = 0.0;
+    //summ = 0.0;
     /* snp invariants */
     for (j = 0; j < opt->rcategs; j++)
       {
@@ -1828,7 +1827,7 @@ treelike_snp (world_fmt * world, long locus)
 MYREAL
 treelike_snp_unlinked (world_fmt * world, long locus)
 {
-    worldoption_fmt *opt;
+    //worldoption_fmt *opt;
     seqmodel_fmt *seq = world->data->seq[0];
     MYREAL scale;
     contribarr tterm, invariants;
@@ -1845,8 +1844,8 @@ treelike_snp_unlinked (world_fmt * world, long locus)
     freqg = seq->basefrequencies[NUC_G];
     freqt = seq->basefrequencies[NUC_T];
 
-    opt = world->options;
-    seq = world->data->seq[0];
+    //opt = world->options;
+    //seq = world->data->seq[0];
     p = crawlback (world->root->next);
     summ = 0.0;
     /* snp invariants */
@@ -1983,8 +1982,8 @@ void find_rates_fromdata(data_fmt * data, option_fmt * options)
 	    }
 	}
     }
-  n = 0;
-  mean = 0.;
+  //n = 0;
+  //mean = 0.;
   if(options->mu_rates == NULL)
     {
       options->mu_rates = (MYREAL *) mycalloc( loci, sizeof(MYREAL));
@@ -2002,7 +2001,12 @@ void find_rates_fromdata(data_fmt * data, option_fmt * options)
 	{
 	  segreg += (long) (v[locus][sites] > 0); 
 	}
-      options->mu_rates[locus] = watterson(segreg,numind[locus]) + 0.0000001;
+      // originally U use just the plain watterson estimates but
+      // this leads to strange results with highly unequal sequences
+      // now the watterson's theta is adjusted per site
+      // and that is used to generate the relative rate from the data
+      // PB April 3 2011
+      options->mu_rates[locus] = (watterson(segreg,numind[locus]) + 0.0000001)/data->seq[0]->sites[locus];
       n = n + 1;
       delta = options->mu_rates[locus] - mean;
       mean += delta/n;
@@ -2014,7 +2018,7 @@ void find_rates_fromdata(data_fmt * data, option_fmt * options)
 	  options->mu_rates[locus] /= mean;
 	  if(options->progress)
 	    {
-	      fprintf(stdout,"Locus %2li: rate=%f (Watterson's overall Theta = %f)\n",locus+1, options->mu_rates[locus],options->mu_rates[locus] * mean / data->seq[0]->sites[locus]);
+	      fprintf(stdout,"Locus %2li: rate=%f (Watterson's overall Theta = %f)\n",locus+1, options->mu_rates[locus],options->mu_rates[locus] * mean);
 	    }
 	}
     }
