@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 1741 2010-10-23 20:27:28Z beerli $
+$Id: tools.c 1866 2011-04-28 20:03:46Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -1284,7 +1284,7 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
         if (hits != 5)
         {
             nrep = 1;
-            hits =
+            //xcode hits =
                 sscanf (input, "%li %li %li", &world->loci, &world->numpop,
                         &world->numpop2);
             options->replicate = FALSE;
@@ -1630,7 +1630,7 @@ insert_migr_node (world_fmt * world, node * up, node * down,
   node *theNode;
     if (!up->top)
         error ("up has to be a top-node");
-    theNode = showtop (up)->back;
+    //xcode theNode = showtop (up)->back;
     if (*migr_table_counter > 0 && up->tyme > migr_table[0].time)
       {
 	printf("%i> up->type=%c tyme=%f showtop(up)time=%f mig[0]tabletyme=%f\n", myID, up->type, up->tyme, showtop(up)->tyme, migr_table[0].time);
@@ -2435,7 +2435,12 @@ dpsifn (MYREAL *x, long *n, long kode, long m, MYREAL *ans, long *nz,
     /*static */
     MYREAL xm, tt, xq, den, arg, fln, r1m4, r1m5, eps, rln, tol,
     xln, trm[22], tss, tst;
-
+    int i;
+	for(i=0;i<22;i++)
+        trm[i]=0.0;
+    for(i=0;i<100;i++)
+        trmr[i]=0.0;
+    
     /* Parameter adjustments */
     --ans;
 
@@ -2469,7 +2474,8 @@ dpsifn (MYREAL *x, long *n, long kode, long m, MYREAL *ans, long *nz,
     }
     mm = m;
     /* Computing MIN */
-    i1 = -fifteen, i2 = sixteen;
+    //xcode i1 = -fifteen;
+    //xcode i2 = sixteen;
     nx = MIN (-i1mach (fifteen), i1mach (sixteen));
     r1m5 = d1mach (five);
     r1m4 = d1mach (four) * .5;
@@ -2914,7 +2920,8 @@ probchiboundary (MYREAL chi, long zeros, long all)
 {
     long nonzeros = all - zeros;
 
-    MYREAL a, b, m;
+//xcode    MYREAL a, b, m;
+    MYREAL m;
     MYREAL xb = 1.0;  //1.0-EPSILON/1000.;
     MYREAL xa = 0.0;  //EPSILON/1000.;
     MYREAL xm = 0.51;
@@ -2924,20 +2931,20 @@ probchiboundary (MYREAL chi, long zeros, long all)
     {
         return probchi (all, chi);
     }
-    a = chiboundary (zeros, nonzeros, xa);
+    //xcode a = chiboundary (zeros, nonzeros, xa);
     m = chiboundary (zeros, nonzeros, xm);
-    b = chiboundary (zeros, nonzeros, xb);
+    //xcode b = chiboundary (zeros, nonzeros, xb);
     while (fabs (m - chi) > EPSILON
             && (fabs (xa - xm) > EPSILON && fabs (xb - xm) > EPSILON))
     {
         if (m < chi)
         {
-            b = m;
+            //xcode b = m;
             xb = xm;
         }
         else
         {
-            a = m;
+            //xcode a = m;
             xa = xm;
         }
         xm =   /*(-(b * xa) + chi * xa + a * xb - chi * xb) / (a - b);      */
@@ -3400,20 +3407,43 @@ void record_warnings(world_fmt * world, const char *fmt, ...)
   myfree(p);
 }
 
+void print_warning2(FILE *file, world_fmt *world)
+{
+      fprintf(file,"\nPOTENTIAL PROBLEMS\n");
+      fprintf(file,"-------------------------------------------------------------------\n");
+      fprintf(file,"This section reports potential problems with your run. Such reporting\n");      
+      fprintf(file,"is tricky. When many parameters in  multilocus analysis\n");      
+      fprintf(file,"are estimated then it is very common that some parameters for some loci\n");      
+      fprintf(file,"will not be very informative, triggering suggestions (for example to\n");
+      fprintf(file,"increase the prior range) that are not sensible. This suggestion tool\n");
+      fprintf(file,"will improve with time. If some parameters are flagged inspect the tables\n");
+      fprintf(file,"carefully and judge wether an action is required. For example if you run\n");
+      fprintf(file,"a Bayesian inference with sequence data, for macroscopic species there is\n");
+      fprintf(file,"rarely the need to increase the prior for Theta beyond 0.1, but if you use\n");
+      fprintf(file,"microsatellites it is rather common that your prior for Theta has a range\n");
+      fprintf(file,"from 0.0 to 100 or more. With many populations (>3) it is also very common\n");      
+      fprintf(file,"that some migration routes are estimated poorly because there is no data.\n");
+      fprintf(file,"Increasing the range will not help in such situations, reducing number of\n");
+      fprintf(file,"parameters may help in such situations.\n\n");
+      fprintf(file,"-------------------------------------------------------------------\n");
+      if (world->warning[0]=='\0')
+	fprintf(file,"No warning was recorded during the run\n\n");
+      else
+	fprintf(file,"%s\n\n", world->warning);
+      fprintf(file,"-------------------------------------------------------------------\n");
+      
+}
+
+
+
 void print_stored_warnings(world_fmt *world)
 {
   if(world->warningsize>0)
     {  
-      fprintf(world->outfile,"\nWARNINGS\n");
-      fprintf(world->outfile,"-------------------------------------------------------------------\n");
-      fprintf(world->outfile,"[You should most likely rerun your analysis after improving run parameters.]\n");
-      fprintf(world->outfile,"%s\n\n", world->warning);
+      print_warning2(world->outfile,world);
       if(world->options->progress)
 	{
-	  fprintf(stdout,"\nWARNINGS\n");
-	  fprintf(stdout,"-------------------------------------------------------------------\n");
-	  fprintf(stdout,"[You should most likely rerun your analysis after improving run parameters.]\n");
-	  fprintf(stdout,"%s\n\n", world->warning);
+	  print_warning2(stdout,world);
 	}
     }
 }
